@@ -1,3 +1,6 @@
+from contextlib import contextmanager
+
+
 class _MetaSingleton(type):
     _instance = {}
 
@@ -41,20 +44,11 @@ class DBHelper(metaclass=_MetaSingleton):
     def flush(self):
         return self.db.session.flush()
 
+    @contextmanager
     def auto_commit(self):
-        return _Commit(db=self.db)
 
-
-class _Commit(metaclass=_MetaSingleton):
-    def __init__(self, db):
-        self._db = db
-
-    def __enter__(self):
-        return self._db
-
-    def __exit__(self, exc_type, exc_val, exc_tb):
         try:
-            yield
-            self._db.session.commit()
+            yield self.db
+            self.db.commit()
         except Exception as e:
-            self._db.session.rollback()
+            self.db.rollback()
